@@ -1,6 +1,8 @@
 class Anomaly(dict):
 	"""
-	Anomaly is an abstract class to be overriden for a specific anomaly and its type.
+	Description: 	Anomaly is an abstract class to be overriden for a specific anomaly and its type.
+
+	:return:
 
 	Implement: TYPE, on_tick
 	"""
@@ -8,16 +10,29 @@ class Anomaly(dict):
 	TYPE = None
 
 	def is_closed(self):
+		"""
+		Description:
+
+		:return:
+		"""
 		return self.get("status") == "closed"
 
 	def close(self, current_time):
+		"""
+		Description:
+
+		:return:
+		"""
 		self["ts_end"] = current_time
 		self["D"] = self["ts_end"] - self["@timestamp"]
 		self["status"] = "closed"
 
 	async def on_tick(self, current_time):
 		"""
-		Implement to perform operations on the anomaly, f. e. close.
-		:param current_time:
+		Description:
+
+		:return:
+
+		:hint: Implement to perform operations on the anomaly, f. e. close.
 		"""
 		raise NotImplementedError()
