@@ -2,4 +2,9 @@ from .processor import ProcessorBase
 
 
 class Sink(ProcessorBase):
+	"""
+	Description:
+
+	:return:
+	"""
 	pass
