@@ -3,9 +3,6 @@ from .timewindowanalyzer import TimeWindowAnalyzer
 from .timedriftanalyzer import TimeDriftAnalyzer
 from .sessionanalyzer import SessionAnalyzer
 from .geoanalyzer import GeoAnalyzer
-from .geomatrix import GeoMatrix
-from .timewindowmatrix import TimeWindowMatrix
-from .sessionmatrix import SessionMatrix
 from .latch import LatchAnalyzer
 from .analyzingsource import AnalyzingSource
 from .threshold import ThresholdAnalyzer
@@ -17,9 +14,6 @@ __all__ = (
 	'TimeDriftAnalyzer',
 	'SessionAnalyzer',
 	'GeoAnalyzer',
-	'GeoMatrix',
-	'TimeWindowMatrix',
-	'SessionMatrix',
 	'LatchAnalyzer',
 	'AnalyzingSource',
 	'ThresholdAnalyzer',
