@@ -2,17 +2,22 @@ import signal
 import sys
 
 import asab
+import asab.web
 
 from .service import BSPumpService
 from .__version__ import __version__, __build__
 
 
 class BSPumpApplication(asab.Application):
+
+
 	"""
-	Application object for BSPump.
+	Description: BSPumpApplication is **class** used for .....
+
+	:return:
 	"""
 
-	def __init__(self, args=None, web_listen=None):
+	def __init__(self, args=None):
 		super().__init__(args=args)
 
 		# Banner
@@ -27,34 +32,30 @@ class BSPumpApplication(asab.Application):
 		self.PumpService = BSPumpService(self)
 		self.WebContainer = None
 
-		# Conditionally activate LogMan.io service
-		if asab.Config.has_section("logman.io"):
-			from asab.logman import Module
-			self.add_module(Module)
-			logman_service = self.get_service('asab.LogManIOService')
-			logman_service.configure_metrics(self.get_service('asab.MetricsService'))
-			logman_service.configure_logging(self)
-
 		try:
 			# Signals are not available on Windows
 			self.Loop.add_signal_handler(signal.SIGUSR1, self._on_signal_usr1)
 		except (NotImplementedError, AttributeError):
 			pass
 
-		# Activate web frontend, if requested
-		if web_listen is None:
-			if self._web_listen is not None and len(self._web_listen) > 0:
-				web_listen = self._web_listen
-			elif "bspump:web" in asab.Config:
-				web_listen = asab.Config["bspump:web"].get("listen", "")
+		# Register bspump API endpoints, if requested (the web service is present)
+		if asab.Config["web"].get("listen"):
 
-		if web_listen is not None and len(web_listen) > 0:
-			from .web import _initialize_web
-			self.WebContainer = _initialize_web(self, web_listen)
+			# Initialize API service
+			self.add_module(asab.web.Module)
 
+			self.WebService = self.get_service("asab.WebService")
+
+			from .web import initialize_web
+			self.WebContainer = initialize_web(self.WebService.WebContainer)
 
 
 	def create_argument_parser(self):
+		"""
+		Description:
+
+		:return:
+		"""
 		prog = sys.argv[0]
 		if prog[-11:] == '__main__.py':
 			prog = sys.executable + " -m bspump"
@@ -75,25 +76,20 @@ build: {} [{}]
 		return parser
 
 
-	def parse_arguments(self, args=None):
-		args = super().parse_arguments(args=args)
-		self._web_listen = args.web_api
-		return args
-
-
 	async def main(self):
 		print("{} pipeline(s) ready.".format(len(self.PumpService.Pipelines)))
-		# TODO: Come up with solution how to reconsile this with unittests, maybe as follows?
-		# L.log(31, "{} pipeline(s) ready.".format(len(self.PumpService.Pipelines)))
-		pass
 
 
 	def _on_signal_usr1(self):
-		'''
-		To clear reset from all pipelines, run
+		"""
+		Description:
+
+		:return:
+
+		:hint: To clear reset from all pipelines, run
 		$ kill -SIGUSR1 xxxx
 		Equivalently, you can use `docker kill -s SIGUSR1 ....` to reset containerized BSPump.
-		'''
+		"""
 		# Reset errors from all pipelines
 		for pipeline in self.PumpService.Pipelines.values():
 			if not pipeline.is_error():
