@@ -1,2 +1,7 @@
 from .cachedict import CacheDict
 from .lrucachedict import LRUCacheDict
+
+__all__ = (
+	'CacheDict',
+	'LRUCacheDict',
+)
