@@ -1,29 +1,17 @@
 import json
-import simdjson
+import cysimdjson
 from ..abc.processor import Processor
 
 
-class DictToJsonParser(Processor):
-
-	def process(self, context, event):
-		return simdjson.dumps(event)
-
-
-class JsonToDictParser(Processor):
-
-	def process(self, context, event):
-		return simdjson.loads(event)
-
-
-class SimdJsonParser(Processor):
+class CySimdJsonParser(Processor):
 	'''
-	Fast JSON parser.
-	Based on https://github.com/TkTech/pysimdjson
+	Fast JSON parser. Expects json bytes represented as bytes as input
+	Based on https://github.com/TeskaLabs/cysimdjson
 	'''
 
 	def __init__(self, app, pipeline, id=None, config=None):
 		super().__init__(app, pipeline, id, config)
-		self._parser = simdjson.Parser()
+		self._parser = cysimdjson.JSONParser()
 
 	def process(self, context, event: bytes):
 		return self._parser.parse(event)
@@ -39,3 +27,21 @@ class StdJsonToDictParser(Processor):
 
 	def process(self, context, event):
 		return json.loads(event)
+
+
+class DictToJsonBytesParser(Processor):
+	"""
+	DictToJsonBytesParser transforms a dictionary to JSON-string encoded in bytes.
+	The encoding charset can be specified in the configuration in `encoding` field.
+	"""
+	ConfigDefaults = {
+		'encoding': 'utf-8',
+	}
+
+	def __init__(self, app, pipeline, id=None, config=None):
+		super().__init__(app, pipeline, id, config)
+		self.Encoding = self.Config['encoding']
+
+	def process(self, context, event):
+		assert isinstance(event, dict)
+		return json.dumps(event).encode(self.Encoding)
