@@ -1,5 +1,5 @@
-from .aes import EncryptAESProcessor
 from .aes import DecryptAESProcessor
+from .aes import EncryptAESProcessor
 from .hashing import HashingProcessor, CoHashingProcessor
 
 '''
@@ -7,4 +7,11 @@ Test AES
 
 openssl aes-128-cbc -e -in /etc/services -K 00000000000000000000000000000000 -iv 00000000000000000000000000000000
 
-'''
\ No newline at end of file
+'''
+
+__all__ = (
+	'EncryptAESProcessor',
+	'DecryptAESProcessor',
+	'HashingProcessor',
+	'CoHashingProcessor',
+)
