@@ -3,6 +3,7 @@ from .generator import DeclarativeGenerator
 from .timewindowanalyzer import DeclarativeTimeWindowAnalyzer
 
 from .builder import ExpressionBuilder
+from .optimizer import ExpressionOptimizer
 from .declerror import DeclarationError
 from .segmentbuilder import SegmentBuilder
 
@@ -11,8 +12,9 @@ from .libraries import FileDeclarationLibrary
 from .libraries import ZooKeeperDeclarationLibrary
 
 from .abc import Expression
+from .abc import SequenceExpression
 
-from .dot import declaration_to_dot
+from .dot import declaration_to_dot, declaration_to_dot_stream
 
 __all__ = [
 	"DeclarativeProcessor",
@@ -23,11 +25,15 @@ __all__ = [
 	"DeclarationError",
 	"SegmentBuilder",
 
+	"ExpressionOptimizer",
+
 	"DeclarationLibrary",
 	"FileDeclarationLibrary",
 	"ZooKeeperDeclarationLibrary",
 
 	"Expression",
+	"SequenceExpression",
 
 	"declaration_to_dot",
+	"declaration_to_dot_stream",
 ]
