@@ -1,6 +1,7 @@
 import datetime
 
-from ...abc import Expression, evaluate
+from ...abc import Expression
+from ..value.valueexpr import VALUE
 
 
 class DATETIME_FORMAT(Expression):
@@ -11,14 +12,28 @@ class DATETIME_FORMAT(Expression):
 	Format example: "%Y-%m-%d %H:%M:%S"
 	"""
 
+	Attributes = {
+		"Format": ["*"],  # TODO: This ...
+		"Value": ["*"],  # TODO: This ...
+	}
+
+	Category = "Date/Time"
+
+
 	def __init__(self, app, *, arg_format, arg_with=None):
 		super().__init__(app)
-		self.Format = arg_format
 		self.Value = arg_with if arg_with is not None else datetime.datetime.utcnow()
+		if not isinstance(self.Value, Expression):
+			self.Value = VALUE(app, value=self.Value)
+
+		if not isinstance(arg_format, Expression):
+			self.Format = VALUE(app, value=arg_format)
+		else:
+			self.Format = arg_format
 
 	def __call__(self, context, event, *args, **kwargs):
-		fmt = evaluate(self.Format, context, event, *args, **kwargs)
-		value = evaluate(self.Value, context, event, *args, **kwargs)
+		fmt = self.Format(context, event, *args, **kwargs)
+		value = self.Value(context, event, *args, **kwargs)
 		if isinstance(value, int) or isinstance(value, float):
 			value = datetime.datetime.fromtimestamp(value)
 		return value.strftime(fmt)
