@@ -1,7 +1,8 @@
 import datetime
 import pytz
 
-from ...abc import Expression, evaluate
+from ...abc import Expression
+from ..value.valueexpr import VALUE
 
 
 class DATETIME_PARSE(Expression):
@@ -12,10 +13,26 @@ class DATETIME_PARSE(Expression):
 	Format example: "%Y-%m-%d %H:%M:%S"
 	"""
 
+	Attributes = {
+		"Value": ["*"],  # TODO: This ...
+		"Format": ["*"],  # TODO: This ...
+		"Timezone": ["*"],  # TODO: This ...
+	}
+
+	Category = "Date/Time"
+
+
 	def __init__(self, app, *, arg_what, arg_format, arg_flags='', arg_timezone=None):
 		super().__init__(app)
-		self.Format = arg_format
-		self.Value = arg_what
+		if not isinstance(arg_what, Expression):
+			self.Value = VALUE(app, value=arg_what)
+		else:
+			self.Value = arg_what
+
+		if not isinstance(arg_format, Expression):
+			self.Format = VALUE(app, value=arg_format)
+		else:
+			self.Format = arg_format
 
 		self.SetCurrentYear = 'Y' in arg_flags
 
@@ -26,8 +43,8 @@ class DATETIME_PARSE(Expression):
 
 
 	def __call__(self, context, event, *args, **kwargs):
-		fmt = evaluate(self.Format, context, event, *args, **kwargs)
-		value = evaluate(self.Value, context, event, *args, **kwargs)
+		fmt = self.Format(context, event, *args, **kwargs)
+		value = self.Value(context, event, *args, **kwargs)
 
 		if isinstance(value, int) or isinstance(value, float):
 			value = datetime.datetime.utcfromtimestamp(value)
