@@ -10,6 +10,14 @@ class IP_FORMAT(Expression):
 	Parses IP address to its string representation.
 	"""
 
+	Attributes = {
+		"Value": ["*"],  # TODO: This ...
+		"Subnet": ["*"],  # TODO: This ...
+	}
+
+	Category = "IP"
+
+
 	def __init__(self, app, *, arg_what, arg_format="auto"):
 		super().__init__(app)
 		self.Value = arg_what
