@@ -1,8 +1,13 @@
-from ...abc import Expression, evaluate
+from ...abc import Expression
 
 
 class LOOKUP_GET(Expression):
 
+	Attributes = {
+		"Key": ["*"],  # TODO: This ...
+		"LookupID": ["*"],  # TODO: This ...
+	}
+
 	def __init__(self, app, *, arg_in, arg_what):
 		super().__init__(app)
 		self.PumpService = app.get_service("bspump.PumpService")
@@ -13,12 +18,19 @@ class LOOKUP_GET(Expression):
 	def build_key(self, context, event, *args, **kwargs):
 		if isinstance(self.Key, (list, tuple)):
 			# Compound key
-			return tuple(
-				evaluate(k, context, event, *args, **kwargs) for k in self.Key
-			)
+			result = list()
+			for k in self.Key:
+				if isinstance(k, (str, int, float)):
+					result.append(k)
+				else:
+					result.append(k(context, event, **kwargs))
+			return tuple(result)
 		else:
 			# Simple key
-			return evaluate(self.Key, context, event, *args, **kwargs)
+			if isinstance(self.Key, (str, int, float)):
+				return self.Key
+			else:
+				return self.Key(context, event, **kwargs)
 
 
 	def __call__(self, context, event, *args, **kwargs):
@@ -29,6 +41,11 @@ class LOOKUP_GET(Expression):
 
 class LOOKUP_CONTAINS(LOOKUP_GET):
 
+	Attributes = {
+		"Key": ["*"],  # TODO: This ...
+		"LookupID": ["*"],  # TODO: This ...
+	}
+
 	def __call__(self, context, event, *args, **kwargs):
 		lookup = self.PumpService.locate_lookup(self.LookupID, context)
 		key = self.build_key(context, event, *args, **kwargs)
