@@ -3,6 +3,13 @@ from ...abc import Expression, evaluate
 
 class FOR(Expression):
 
+	Attributes = {
+		"Each": ["*"],  # TODO: This ...
+		"Do": ["*"],  # TODO: This ...
+	}
+
+	Category = 'Statements'
+
 
 	def __init__(self, app, *, arg_each, arg_do):
 		super().__init__(app)
