@@ -11,9 +11,10 @@ L = logging.getLogger("bspump.declarative.DEBUG")
 
 
 class DEBUG(Expression):
-	"""
-	Transform "string" to lowercase.
-	"""
+
+	Attributes = {
+		"What": ["*"],  # TODO: This ...
+	}
 
 	def __init__(self, app, *, arg_what):
 		super().__init__(app)
