@@ -11,6 +11,10 @@ Usage:
 ``
 	"""
 
+	Attributes = {}
+
+	Category = "Value"
+
 	def __init__(self, app, *, value):
 		super().__init__(app)
 		assert(value == "")
@@ -18,6 +22,9 @@ Usage:
 	def __call__(self, context, event, *args, **kwargs):
 		return event
 
+	def get_outlet_type(self):
+		return dict.__name__
+
 
 class KWARGS(Expression):
 	"""
@@ -29,6 +36,12 @@ Usage:
 ``
 	"""
 
+	Attributes = {}
+
+	Category = "Value"
+
+
+
 	def __init__(self, app, *, value):
 		super().__init__(app)
 		assert(value == "")
@@ -48,6 +61,9 @@ Usage:
 ``
 	"""
 
+	Attributes = {}
+	Category = "Value"
+
 	def __init__(self, app, *, value):
 		super().__init__(app)
 		self.ArgName = value
@@ -57,6 +73,10 @@ Usage:
 
 
 class ARGS(Expression):
+
+	Attributes = {}
+	Category = "Value"
+
 	def __init__(self, app, *, value):
 		super().__init__(app)
 		assert(value == '')
@@ -66,6 +86,10 @@ class ARGS(Expression):
 
 
 class ARG(Expression):
+
+	Attributes = {}
+	Category = "Value"
+
 	def __init__(self, app, *, value):
 		super().__init__(app)
 		assert(value == '')
