@@ -3,7 +3,6 @@ import logging
 import random
 import re
 
-import orjson
 import aiohttp
 
 from ..abc.connection import Connection
@@ -16,6 +15,11 @@ L = logging.getLogger(__name__)
 
 
 class ElasticSearchBulk(object):
+	"""
+	Description:
+
+	:return:
+	"""
 
 	def __init__(self, connection, index, max_size):
 		self.Index = index
@@ -26,13 +30,34 @@ class ElasticSearchBulk(object):
 		self.FailLogMaxSize = connection.FailLogMaxSize
 		self.FilterPath = connection.FilterPath
 
-	def consume(self, _id, data):
-		self.Items.append((_id, data))
-		self.Capacity -= len(data)
+	def consume(self, data_feeder_generator):
+		"""
+		Description:
+
+		:return:
+		"""
+		for item in data_feeder_generator:
+			self.Items.append(item)
+			self.Capacity -= len(item)
+
 		self.Aging = 0
 		return self.Capacity <= 0
 
+	async def _get_data_from_items(self):
+		"""
+		Description:
+
+		:return:
+		"""
+		for item in self.Items:
+			yield item
+
 	async def upload(self, url, session, timeout):
+		"""
+		Description:
+
+		:return:
+		"""
 		items_count = len(self.Items)
 		if items_count == 0:
 			return
@@ -42,7 +67,7 @@ class ElasticSearchBulk(object):
 		try:
 			resp = await session.post(
 				url,
-				data=self._data_feeder(),
+				data=self._get_data_from_items(),
 				headers={
 					'Content-Type': 'application/json'
 				},
@@ -115,28 +140,25 @@ class ElasticSearchBulk(object):
 
 		return True
 
-
-	async def _data_feeder(self):
-		for _id, data in self.Items:
-			yield b'{"create":{}}\n' if _id is None else orjson.dumps(
-				{"index": {"_id": _id}}, option=orjson.OPT_APPEND_NEWLINE
-			)
-			yield data
-
 	def partial_error_callback(self, response_items):
 		"""
-		When an upload to ElasticSearch fails for error items (document could not be inserted),
+		Description: When an upload to ElasticSearch fails for error items (document could not be inserted),
 		this callback is called.
+
 		:param response_items: list with dict items: {"index": {"_id": ..., "error": ...}}
+
 		:return:
 		"""
 
 	def full_error_callback(self, bulk_items, return_code):
 		"""
-		When an upload to ElasticSearch fails b/c of ElasticSearch error,
+		Description: When an upload to ElasticSearch fails b/c of ElasticSearch error,
 		this callback is called.
+
 		:param bulk_items: list with tuple items: (_id, data)
+
 		:param return_code: ElasticSearch return code
+
 		:return: False if the bulk is to be resumbitted again
 		"""
 		return False
@@ -144,29 +166,9 @@ class ElasticSearchBulk(object):
 
 class ElasticSearchConnection(Connection):
 	"""
+	Description:
 
-	ElasticSearchConnection allows your ES source, sink or lookup to connect to ElasticSearch instance
-
-	usage:
-
-.. code:: python
-
-
-	# adding connection to PumpService
-	svc = app.get_service("bspump.PumpService")
-	svc.add_connection(
-		bspump.elasticsearch.ElasticSearchConnection(app, "ESConnection")
-	)
-
-.. code:: python
-
-	# pass connection name ("ESConnection" in our example) to relevant BSPump's object:
-
-	self.build(
-			bspump.kafka.KafkaSource(app, self, "KafkaConnection"),
-			bspump.elasticsearch.ElasticSearchSink(app, self, "ESConnection")
-	)
-
+	:return:
 	"""
 
 	ConfigDefaults = {
@@ -183,6 +185,11 @@ class ElasticSearchConnection(Connection):
 	}
 
 	def __init__(self, app, id=None, config=None):
+		"""
+		Description:
+
+		:return:
+		"""
 		super().__init__(app, id=id, config=config)
 
 		self._output_queue_max_size = int(self.Config['output_queue_max_size'])
@@ -251,27 +258,56 @@ class ElasticSearchConnection(Connection):
 		)
 
 	def get_url(self):
+		"""
+		Description:
+
+		:return:
+		"""
 		return random.choice(self.node_urls)
 
 	def get_session(self):
+		"""
+		Description:
+
+		:return:
+		"""
 		return aiohttp.ClientSession(auth=self._auth, loop=self.Loop)
 
-	def consume(self, index, _id, data, bulk_class=ElasticSearchBulk):
+	def consume(self, index, data_feeder_generator, bulk_class=ElasticSearchBulk):
+		"""
+		Description:
+
+		:return:
+		"""
+		if data_feeder_generator is None:
+			return
+
 		bulk = self._bulks.get(index)
 		if bulk is None:
 			bulk = bulk_class(self, index, self._bulk_out_max_size)
 			self._bulks[index] = bulk
 
-		if bulk.consume(_id, data):
+		if bulk.consume(data_feeder_generator):
 			# Bulk is ready, schedule to be send
 			del self._bulks[index]
+			self._bulks[index] = None
 			self.enqueue(bulk)
 
-	def _start(self, event_type):
+	def _start(self, event_name):
+		"""
+		Description:
+
+		:return:
+		"""
 		self.PubSub.subscribe("Application.tick!", self._on_tick)
 		self._on_tick("simulated!")
 
 	async def _on_exit(self, event_name):
+		"""
+		Description:
+
+		:return:
+		"""
 		# Wait till the queue is empty
 		self.flush(forced=True)
 		while self._output_queue.qsize() > 0:
@@ -292,6 +328,11 @@ class ElasticSearchConnection(Connection):
 
 
 	def _on_tick(self, event_name):
+		"""
+		Description:
+
+		:return:
+		"""
 		self.QueueMetric.set("size", int(self._output_queue.qsize()))
 
 		for i in range(len(self._futures)):
@@ -319,6 +360,11 @@ class ElasticSearchConnection(Connection):
 		self.flush()
 
 	def flush(self, forced=False):
+		"""
+		Description:
+
+		:return:
+		"""
 		aged = []
 		for index, bulk in self._bulks.items():
 			bulk.Aging += 1
@@ -330,9 +376,11 @@ class ElasticSearchConnection(Connection):
 			self.enqueue(bulk)
 
 	def enqueue(self, bulk):
-		'''
-		Properly enqueue the bulk.
-		'''
+		"""
+		Description: Properly enqueue the bulk.
+
+		:return:
+		"""
 		self._output_queue.put_nowait(bulk)
 
 		# Signalize need for throttling
@@ -340,6 +388,11 @@ class ElasticSearchConnection(Connection):
 			self.PubSub.publish("ElasticSearchConnection.pause!", self)
 
 	async def _loader(self, url):
+		"""
+		Description:
+
+		:return:
+		"""
 		async with self.get_session() as session:
 
 			# Preflight check
@@ -381,3 +434,7 @@ class ElasticSearchConnection(Connection):
 					self.enqueue(bulk)
 					await asyncio.sleep(5)  # Throttle a bit before next try
 					break  # Exit the loader (new will be started automatically)
+
+
+				# Make sure the memory is emptied
+				bulk.Items = []
