@@ -1,4 +1,3 @@
-import abc
 import asyncio
 import logging
 import os
@@ -68,6 +67,7 @@ class FileABCSource(TriggerSource):
 		)
 
 		self.Loop = app.Loop
+		self.ProactorService = app.get_service("asab.ProactorService")
 
 		self.LinesCounter = 0
 		self.LinesPerEvent = int(self.Config["lines_per_event"])
@@ -78,7 +78,16 @@ class FileABCSource(TriggerSource):
 
 		start_time = time.time()
 		for path in self.path.split(os.pathsep):
-			filename = _glob_scan(path, self.Gauge, self.Loop, exclude=self.exclude, include=self.include)
+			# Asynchronously call following:
+			# filename = _glob_scan(path, self.Gauge, self.Loop, exclude=self.exclude, include=self.include)
+			filename = await self.ProactorService.execute(
+				_glob_scan,
+				path,
+				self.Gauge,
+				self.Loop,
+				self.exclude,
+				self.include
+			)
 			if filename is not None:
 				break
 		end_time = time.time()
@@ -188,7 +197,6 @@ class FileABCSource(TriggerSource):
 			await asyncio.sleep(self.EventIdleTime)
 			self.LinesCounter = 0
 
-	@abc.abstractmethod
 	async def read(self, filename, f):
 		'''
 		Override this method to implement your File Source.
