@@ -18,8 +18,10 @@ if platform.system() == "Windows":
 		return False
 else:
 	def _is_file_open(fname):
-		result = subprocess.run(['lsof', fname], stdout=subprocess.PIPE)
-		return len(result.stdout) != 0
+		# TODO: Provide implementation of _is_file_open() for Linux
+		# result = subprocess.run(['lsof', fname], stdout=subprocess.PIPE)
+		# return len(result.stdout) != 0
+		return False
 
 
 def _glob_scan(path, gauge, loop, exclude='', include=''):
@@ -35,7 +37,7 @@ def _glob_scan(path, gauge, loop, exclude='', include=''):
 	filelist_to_check.extend(filelist)
 
 	# also check the whole folder meanwhile
-	loop.call_soon(_file_check, filelist_to_check, gauge)
+	loop.call_soon_threadsafe(_file_check, filelist_to_check, gauge)
 
 	while len(filelist) > 0:
 		fname = filelist.pop(0)
