@@ -1,4 +1,3 @@
-import abc
 import re
 import logging
 import asyncio
@@ -76,14 +75,19 @@ class HTTPABCClientSource(TriggerSource):
 			self.FailedResponses += 1
 			if self.FailedResponses < self.MaxFailedResponses:
 				L.warning("{}, will retry ({}/{}) in {:0.0f} sec".format(e, self.FailedResponses, self.MaxFailedResponses, self.FailChilldown))
+
+
+				self.Pipeline.MetricsEPSCounter.add('warning', 1)
 				self.Pipeline.MetricsCounter.add('warning', 1)
+
+				self.Pipeline.MetricsEPSCounter.add('eps.in', 1)
+				self.Pipeline.MetricsCounter.add('event.in', 1)
 				await asyncio.sleep(self.FailChilldown)
 			else:
 				L.error("{}, {} failed response(s)".format(e, self.FailedResponses))
 				raise aiohttp.ClientError("{}, url='{}'".format(e, self.URL))
 
 
-	@abc.abstractmethod
 	async def read(self, response):
 		'''
 		Override this method to implement your HTTP Source.
