@@ -123,6 +123,11 @@ class KafkaSink(Sink):
 
 
 	def _on_health_check(self, message_type):
+		"""
+		Description:
+
+		:returns:
+		"""
 		if self._conn_future is not None:
 			# Connection future exists
 
@@ -149,10 +154,20 @@ class KafkaSink(Sink):
 
 
 	def _on_application_stop(self, message_type, counter):
+		"""
+		Description:
+
+		:returns:
+		"""
 		self._output_queue.put_nowait((None, None, None))
 
 
 	async def _connection(self):
+		"""
+		Description:
+
+		:returns:
+		"""
 		producer = await self.Connection.create_producer(**self._producer_params)
 		try:
 			await producer.start()
@@ -172,6 +187,11 @@ class KafkaSink(Sink):
 
 
 	def process(self, context, event: typing.Union[dict, str, bytes]):
+		"""
+		Description:
+
+		:returns:
+		"""
 		if type(event) == dict:
 			event = json.dumps(event)
 			event = event.encode(self.Encoding)
