@@ -2,3 +2,11 @@ from .connection import MySQLConnection
 from .source import MySQLSource
 from .sink import MySQLSink
 from .lookup import MySQLLookup
+
+
+__all__ = (
+	'MySQLConnection',
+	'MySQLSource',
+	'MySQLSink',
+	'MySQLLookup',
+)
