@@ -1,9 +1,6 @@
-import datetime
-
-import asab
-
 from ..abc.sink import Sink
 
+
 class MySQLSink(Sink):
 
 
