@@ -1,21 +1,23 @@
-import asab
-import asyncio
 import logging
+
+import pymysql
+import pymysql.cursors
+import pymysql.err
+
 import aiomysql.cursors
+
 from ..abc.source import TriggerSource
 
-#
 
 L = logging.getLogger(__name__)
 
-#
 
 class MySQLSource(TriggerSource):
 
 	ConfigDefaults = {
 		'query': ''
 	}
-	
+
 	def __init__(self, app, pipeline, connection, id=None, config=None):
 		super().__init__(app, pipeline, id=id, config=config)
 		self.Loop = app.Loop
@@ -26,8 +28,8 @@ class MySQLSource(TriggerSource):
 
 	async def cycle(self):
 		await self._connection.ConnectionEvent.wait()
-		async with self._connection.acquire() as connection:
-			try:
+		try:
+			async with self._connection.acquire_connection() as connection:
 				async with connection.cursor(aiomysql.cursors.SSCursor) as cur:
 					await cur.execute(self._query)
 					event = {}
@@ -44,5 +46,7 @@ class MySQLSource(TriggerSource):
 						# Pass event to the pipeline
 						await self.process(event)
 					await cur.execute("COMMIT;")
-			except BaseException as e:
-				L.exception("Unexpected error when processing MySQL query.")
+		except (pymysql.err.InternalError, pymysql.err.ProgrammingError, pymysql.err.OperationalError) as e:
+			if e.args[0] in self._connection.RetryErrors:
+				L.warn("Recoverable error '{}' occurred in MySQLSource. Retrying.".format(e.args[0]))
+			raise e
