@@ -1,10 +1,11 @@
 from .connection import PostgreSQLConnection
 from .sink import PostgreSQLSink
 from .logicalreplicationsource import PostgreSQLLogicalReplicationSource
-
+from .lookup import PostgreSQLLookup
 
 __all__ = (
 	'PostgreSQLConnection',
 	'PostgreSQLSink',
 	'PostgreSQLLogicalReplicationSource',
+	'PostgreSQLLookup',
 )
