@@ -1,6 +1,5 @@
 from .randomdrop import RandomDrop
 from .source import RandomSource
-from .randomsource import RandomGeneratorSource
 from .randomenricher import RandomEnricher
 
 
@@ -8,5 +7,4 @@ __all__ = (
 	'RandomDrop',
 	'RandomSource',
 	'RandomEnricher',
-	'RandomGeneratorSource',
 )
