@@ -10,7 +10,7 @@ class RandomEnricher(Processor):
 		a) User provides `choice` as an array of values to choice randomly and assigned to field;
 		b) The random integer between `Config['lower_bound']` and `Config['upper_bound']`.
 	'''
-	
+
 	ConfigDefaults = {
 		'field': 'enriched_field',
 		'lower_bound': 0,
@@ -31,11 +31,11 @@ class RandomEnricher(Processor):
 		'''
 			Override this method to generate differently
 		'''
-		if self.Choice:
+		if self.Choice is not None:
 			event[self.Field] = random.choice(self.Choice)
 		else:
 			n = random.randint(self.LowerBound, self.UpperBound)
-			event[self.Field] = "{}".format(n)
+			event[self.Field] = n
 
 
 	def process(self, context, event):
