@@ -15,7 +15,7 @@ class TestDeclarativeDateTime(bspump.unittest.TestCase):
 	def load(self, decl_fname):
 		basedir = os.path.dirname(__file__)
 		with open(os.path.join(basedir, decl_fname), 'r') as f:
-			return self.Builder.parse(f.read())
+			return self.Builder.parse(f.read())[0]
 
 
 	def test_datetime_parse_set_year(self):
